@@ -6,7 +6,6 @@ Dotty Grid implementation of PointDetector.
 
 # pylint:disable=too-many-instance-attributes
 
-import copy
 import logging
 import cv2
 import numpy as np
@@ -15,9 +14,9 @@ from sksurgeryimage.calibration.point_detector import PointDetector
 LOGGER = logging.getLogger(__name__)
 
 
-def get_model_points(dots_rows_columns: (int, int),
-                     pixels_per_mm: int,
-                     dot_separation: float) -> np.ndarray:
+def create_model_points(dots_rows_columns: (int, int),
+                        pixels_per_mm: int,
+                        dot_separation: float) -> np.ndarray:
     """Generate the expected locations of dots in the pattern, in pixel space.
 
     :param dots_rows_columns: Number of rows, number of columns
@@ -52,6 +51,7 @@ class DottyGridPointDetector(PointDetector):
 
     More specifically, a grid of dots with 4 larger dots at known locations.
     """
+    # pylint: disable=too-many-arguments
     def __init__(self,
                  model_points,
                  list_of_indexes,
@@ -93,7 +93,7 @@ class DottyGridPointDetector(PointDetector):
         :param max_area: maximum area when filtering by area
         :param dot_detector_params: instance of cv2.SimpleBlobDetector_Params()
         """
-        super(DottyGridPointDetector, self).\
+        super().\
             __init__(scale=scale,
                      camera_intrinsics=camera_intrinsics,
                      distortion_coefficients=distortion_coefficients
@@ -399,6 +399,12 @@ class DottyGridPointDetector(PointDetector):
 
     def get_model_points(self):
         """
-        Returns a [Nx3] numpy ndarray representing the model points in 3D.
+        If you look in base class, this is expected to return Dict[int, np.ndarray]
         """
-        return copy.deepcopy(self.model_points[:, 3:6])
+        result_dict = {}
+        # pylint: disable=consider-using-enumerate
+        for i in range(len(self.model_points)):
+            point_id = int(self.model_points[i][0])
+            point_coords = self.model_points[i][3:6]
+            result_dict[point_id] = point_coords
+        return result_dict
